import { aws_ec2 as ec2, aws_rds as rds, aws_secretsmanager as secretsmanager } from "aws-cdk-lib";
import { PythonFunction, PythonFunctionProps } from "@aws-cdk/aws-lambda-python-alpha";
import { IDomainName } from "@aws-cdk/aws-apigatewayv2-alpha";
import { Construct } from "constructs";
export declare class TiPgApiLambda extends Construct {
    readonly url: string;
    tiPgLambdaFunction: PythonFunction;
    constructor(scope: Construct, id: string, props: TiPgApiLambdaProps);
}
export interface TiPgApiLambdaProps {
    /**
     * VPC into which the lambda should be deployed.
     */
    readonly vpc: ec2.IVpc;
    /**
     * RDS Instance with installed pgSTAC.
     */
    readonly db: rds.IDatabaseInstance;
    /**
     * Subnet into which the lambda should be deployed.
     */
    readonly subnetSelection: ec2.SubnetSelection;
    /**
     * Secret containing connection information for pgSTAC database.
     */
    readonly dbSecret: secretsmanager.ISecret;
    /**
     * Custom code to run for fastapi-pgstac.
     *
     * @default - simplified version of fastapi-pgstac
     */
    readonly apiCode?: TiPgApiEntrypoint;
    /**
     * Customized environment variables to send to titiler-pgstac runtime.
     */
    readonly apiEnv?: Record<string, string>;
    /**
     * Custom Domain Name for tipg API. If defined, will create the
     * domain name and integrate it with the tipg API.
     *
     * @default - undefined
     */
    readonly tipgApiDomainName?: IDomainName;
}
export interface TiPgApiEntrypoint {
    /**
     * Path to the source of the function or the location for dependencies.
     */
    readonly entry: PythonFunctionProps["entry"];
    /**
     * The path (relative to entry) to the index file containing the exported handler.
     */
    readonly index: PythonFunctionProps["index"];
    /**
     * The name of the exported handler in the index file.
     */
    readonly handler: PythonFunctionProps["handler"];
}
