import { aws_ec2 as ec2, aws_rds as rds, aws_lambda as lambda, aws_secretsmanager as secretsmanager } from "aws-cdk-lib";
import { IDomainName } from "@aws-cdk/aws-apigatewayv2-alpha";
import { Construct } from "constructs";
export declare class TitilerPgstacApiLambda extends Construct {
    readonly url: string;
    titilerPgstacLambdaFunction: lambda.Function;
    constructor(scope: Construct, id: string, props: TitilerPgStacApiLambdaProps);
}
export interface TitilerPgStacApiLambdaProps {
    /**
     * VPC into which the lambda should be deployed.
     */
    readonly vpc: ec2.IVpc;
    /**
     * RDS Instance with installed pgSTAC.
     */
    readonly db: rds.IDatabaseInstance;
    /**
     * Subnet into which the lambda should be deployed.
     */
    readonly subnetSelection: ec2.SubnetSelection;
    /**
     * Secret containing connection information for pgSTAC database.
     */
    readonly dbSecret: secretsmanager.ISecret;
    /**
     * Customized environment variables to send to titiler-pgstac runtime.
     */
    readonly apiEnv?: Record<string, string>;
    /**
     * list of buckets the lambda will be granted access to.
     */
    readonly buckets?: string[];
    /**
     * Custom Domain Name Options for Titiler Pgstac API,
     */
    readonly titilerPgstacApiDomainName?: IDomainName;
}
